@@ -22,7 +22,7 @@
 
 #define QT_FEATURE_reduce_exports 1
 
-#define QT_FEATURE_no_direct_extern_access 1
+#define QT_FEATURE_no_direct_extern_access -1
 
 #define QT_FEATURE_x86intrin 1
 
